@@ -3,7 +3,7 @@
 #
 #  (C) Paul Evans, 2019-2023 -- leonerd@leonerd.org.uk
 
-package Object::Pad 0.803;
+package Object::Pad 0.804;
 
 use v5.14;
 use warnings;
@@ -330,6 +330,18 @@ instance is doing even in XS modules.
 This representation type is the only one that will work for subclassing
 existing classes that do not use blessed hashes.
 
+   :repr(pvobj)
+
+I<Since version 0.804.>
+
+The representation will be the C<SVt_PVOBJ> type newly added to Perl, which
+offers more efficient storage for object instances. This is only available on
+Perl version 5.38.0 onwards.
+
+This is also newly-added and may not be fully tested and reliable yet. Once it
+has more real-world testing and has proven reliable it may become the default
+instance representation on versions of Perl where it is available.
+
    :repr(autoselect), :repr(default)
 
 I<Since version 0.23.>
