@@ -5,12 +5,6 @@
 #include "perl.h"
 #include "XSUB.h"
 
-#include "object_pad.h"
-#include "class.h"
-#include "field.h"
-
-#undef register_class_attribute
-
 #ifdef HAVE_DMD_HELPER
 #  define WANT_DMD_API_044
 #  include "DMD_helper.h"
@@ -26,6 +20,12 @@
 #include "newOP_CUSTOM.c.inc"
 #include "cv_copy_flags.c.inc"
 
+#include "object_pad.h"
+#include "class.h"
+#include "field.h"
+
+#undef register_class_attribute
+
 #ifdef DEBUGGING
 #  define DEBUG_OVERRIDE_PLCURCOP
 #  define DEBUG_SET_CURCOP_LINE(line)    CopLINE_set(PL_curcop, line)
@@ -259,8 +259,8 @@ SV *ObjectPad_mop_class_get_name(pTHX_ ClassMeta *class)
   return class->name;
 }
 
-#define make_instance_fields(classmeta, backingav, roleoffset)  S_make_instance_fields(aTHX_ classmeta, backingav, roleoffset)
-static void S_make_instance_fields(pTHX_ const ClassMeta *classmeta, AV *backingav, FIELDOFFSET roleoffset)
+#define make_instance_fields(classmeta, fieldstore, roleoffset)  S_make_instance_fields(aTHX_ classmeta, fieldstore, roleoffset)
+static void S_make_instance_fields(pTHX_ const ClassMeta *classmeta, SV *fieldstore, FIELDOFFSET roleoffset)
 {
   assert(classmeta->type == METATYPE_ROLE || roleoffset == 0);
 
@@ -269,13 +269,14 @@ static void S_make_instance_fields(pTHX_ const ClassMeta *classmeta, AV *backing
     assert(classmeta->type == METATYPE_CLASS);
     assert(classmeta->cls.supermeta->sealed);
 
-    make_instance_fields(classmeta->cls.supermeta, backingav, 0);
+    make_instance_fields(classmeta->cls.supermeta, fieldstore, 0);
   }
 
   AV *fields = classmeta->direct_fields;
   I32 nfields = av_count(fields);
 
-  av_extend(backingav, classmeta->next_fieldix - 1 + roleoffset);
+  if(SvTYPE(fieldstore) == SVt_PVAV)
+    av_extend((AV *)fieldstore, classmeta->next_fieldix - 1 + roleoffset);
 
   I32 i;
   for(i = 0; i < nfields; i++) {
@@ -285,7 +286,17 @@ static void S_make_instance_fields(pTHX_ const ClassMeta *classmeta, AV *backing
     FIELDOFFSET fieldix = fieldmeta->fieldix + roleoffset;
 
     /* We can't av_push() because REPR_KEYS would break here */
-    SV **svp = av_fetch_simple(backingav, fieldix, TRUE);
+    SV **svp;
+#ifdef HAVE_SVt_PVOBJ
+    if(SvTYPE(fieldstore) == SVt_PVOBJ) {
+      svp = &ObjectFIELDS(fieldstore)[fieldix];
+      *svp = newSV(0);
+    }
+    else
+#endif
+    {
+      svp = av_fetch_simple((AV *)fieldstore, fieldix, TRUE);
+    }
     assert(svp);
 
     switch(sigil) {
@@ -318,7 +329,7 @@ static void S_make_instance_fields(pTHX_ const ClassMeta *classmeta, AV *backing
 
       assert(rolemeta->sealed);
 
-      make_instance_fields(rolemeta, backingav, embedding->offset);
+      make_instance_fields(rolemeta, fieldstore, embedding->offset);
     }
   }
 }
@@ -344,7 +355,7 @@ static void S_alias_fieldkeys_into_av(pTHX_ ClassMeta *classmeta, HV *hv, AV *ba
   }
 }
 
-SV *ObjectPad_get_obj_backingav(pTHX_ SV *self, enum ReprType repr, bool create)
+SV *ObjectPad_get_obj_fieldstore(pTHX_ SV *self, enum ReprType repr, bool create)
 {
   SV *rv = SvRV(self);
 
@@ -371,12 +382,12 @@ SV *ObjectPad_get_obj_backingav(pTHX_ SV *self, enum ReprType repr, bool create)
        */
       if(!backingsvp) {
         struct ClassMeta *classmeta = mop_get_class_for_stash(SvSTASH(rv));
-        AV *backingav = newAV();
+        SV *fieldstore = (SV *)newAV();
 
-        make_instance_fields(classmeta, backingav, 0);
+        make_instance_fields(classmeta, fieldstore, 0);
 
         backingsvp = hv_fetchs((HV *)rv, "Object::Pad/slots", TRUE);
-        sv_setrv_noinc(*backingsvp, (SV *)backingav);
+        sv_setrv_noinc(*backingsvp, fieldstore);
       }
       if(!SvROK(*backingsvp) || SvTYPE(SvRV(*backingsvp)) != SVt_PVAV)
         croak("Expected $self->{\"Object::Pad/slots\"} to be an ARRAY reference");
@@ -411,11 +422,29 @@ SV *ObjectPad_get_obj_backingav(pTHX_ SV *self, enum ReprType repr, bool create)
       alias_fieldkeys_into_av(mop_get_class_for_stash(SvSTASH(rv)), hv, backingav);
       return (SV *)backingav;
     }
+
+    case REPR_PVOBJ:
+#ifdef HAVE_SVt_PVOBJ
+      if(SvTYPE(rv) != SVt_PVOBJ)
+        croak("ARGH not an SVt_PVOBJ");
+
+      return rv;
+#else
+      croak("ARGH cannot SVt_PVOBJ on this version of perl");
+#endif
   }
 
   croak("ARGH unhandled repr type");
 }
 
+SV *ObjectPad_get_obj_backingav(pTHX_ SV *self, enum ReprType repr, bool create)
+{
+  if(repr == REPR_PVOBJ)
+    croak("ARGH cannot get_obj_backingav for REPR_PVOBJ because it isn't an AV");
+  else
+    return get_obj_fieldstore(self, repr, create);
+}
+
 #define embed_cv(cv, embedding)  S_embed_cv(aTHX_ cv, embedding)
 static CV *S_embed_cv(pTHX_ CV *cv, RoleEmbedding *embedding)
 {
@@ -436,6 +465,18 @@ static CV *S_embed_cv(pTHX_ CV *cv, RoleEmbedding *embedding)
   return embedded_cv;
 }
 
+RoleEmbedding *ObjectPad__get_embedding_from_pad(pTHX)
+{
+  /* Embedding info is stored in pad1; PAD_SVl() will look at CvDEPTH. We'll
+   * have to grab it manually */
+  PAD *pad1 = PadlistARRAY(CvPADLIST(find_runcv(0)))[1];
+  SV *embeddingsv = PadARRAY(pad1)[PADIX_EMBEDDING];
+  if(embeddingsv && embeddingsv != &PL_sv_undef)
+    return (RoleEmbedding *)SvPVX(embeddingsv);
+  else
+    return NULL;
+}
+
 RoleEmbedding **ObjectPad_mop_class_get_direct_roles(pTHX_ const ClassMeta *meta, U32 *nroles)
 {
   assert(meta->type == METATYPE_CLASS);
@@ -586,6 +627,7 @@ OP *ObjectPad__finish_method_parse(pTHX_ ClassMeta *meta, bool is_common, OP *bo
   I32 nfields = av_count(meta->direct_fields);
   PADNAME **snames = PadnamelistARRAY(fieldnames);
   PADNAME **padnames = PadnamelistARRAY(PadlistNAMES(CvPADLIST(PL_compcv)));
+  U8 opf_special_if_role = (meta->type == METATYPE_ROLE) ? OPf_SPECIAL : 0;
 
   /* If we have no body that means this was a bodyless method
    * declaration; a required method for a role
@@ -666,6 +708,7 @@ OP *ObjectPad__finish_method_parse(pTHX_ ClassMeta *meta, bool is_common, OP *bo
       }
 
 #ifdef METHSTART_CONTAINS_FIELD_BINDINGS
+      PERL_UNUSED_VAR(opf_special_if_role);
       assert((fieldix & ~FIELDIX_MASK) == 0);
       av_store(fieldmap, padix, newSVuv(((UV)private << FIELDIX_TYPE_SHIFT) | fieldix));
       fieldcount++;
@@ -674,7 +717,7 @@ OP *ObjectPad__finish_method_parse(pTHX_ ClassMeta *meta, bool is_common, OP *bo
 #else
       fieldops = op_append_list(OP_LINESEQ, fieldops,
         /* alias the padix from the field */
-        newFIELDPADOP(private << 8, padix, fieldix));
+        newFIELDPADOP(private << 8 | opf_special_if_role, padix, fieldix));
 #endif
 
 #if HAVE_PERL_VERSION(5, 22, 0)
@@ -1542,6 +1585,24 @@ XS_INTERNAL(injected_constructor)
         sv_bless(self, stash);
         break;
 
+      case REPR_PVOBJ:
+#ifdef HAVE_SVt_PVOBJ
+        {
+          DEBUG_SET_CURCOP_LINE(__LINE__);
+          /* TODO: Perl needs to export newSVobject() */
+          U32 fieldcount = meta->next_fieldix;
+          SV *obj = newSV_type(SVt_PVOBJ);
+          Newx(ObjectFIELDS(obj), fieldcount, SV *);
+          ObjectMAXFIELD(obj) = fieldcount - 1;
+          Zero(ObjectFIELDS(obj), fieldcount, SV *);
+          self = sv_2mortal(newRV_noinc(obj));
+          sv_bless(self, stash);
+        }
+#else
+        croak("ARGH cannot SVt_PVOBJ on this version of perl");
+#endif
+        break;
+
       case REPR_MAGIC:
         croak("ARGH cannot use :repr(magic) without a foreign superconstructor");
         break;
@@ -1596,6 +1657,8 @@ XS_INTERNAL(injected_constructor)
     switch(meta->repr) {
       case REPR_NATIVE:
         croak("ARGH shouldn't ever have REPR_NATIVE with foreign_new");
+      case REPR_PVOBJ:
+        croak("ARGH shouldn't ever have REPR_PVOBJ with foreign_new");
 
       case REPR_HASH:
       case_REPR_HASH:
@@ -1626,28 +1689,28 @@ XS_INTERNAL(injected_constructor)
     sv_2mortal(self);
   }
 
-  AV *backingav;
+  SV *fieldstore;
 
   if(need_makefields) {
-    backingav = (AV *)get_obj_backingav(self, meta->repr, TRUE);
-    make_instance_fields(meta, backingav, 0);
+    fieldstore = get_obj_fieldstore(self, meta->repr, TRUE);
+    make_instance_fields(meta, fieldstore, 0);
   }
   else {
-    backingav = (AV *)get_obj_backingav(self, meta->repr, FALSE);
+    fieldstore = get_obj_fieldstore(self, meta->repr, FALSE);
   }
 
-  SV **fieldsvs = AvARRAY(backingav);
+  SV **fieldsvs = fieldstore_fields(fieldstore);
 
   if(meta->fieldhooks_makefield || meta->fieldhooks_construct) {
-    /* We need to set up a fake pad so these hooks can still get PADIX_SELF / PADIX_SLOTS */
+    /* We need to set up a fake pad so these hooks can still get PADIX_SELF / PADIX_FIELDS */
 
     /* This MVP is just sufficient enough to let PAD_SVl(PADIX_SELF) work */
     SAVEVPTR(PL_curpad);
     Newx(PL_curpad, 3, SV *);
     SAVEFREEPV(PL_curpad);
 
-    PAD_SVl(PADIX_SELF)  = self;
-    PAD_SVl(PADIX_SLOTS) = (SV *)backingav;
+    PAD_SVl(PADIX_SELF)   = self;
+    PAD_SVl(PADIX_FIELDS) = fieldstore;
   }
 
   if(meta->fieldhooks_makefield) {
@@ -2278,6 +2341,15 @@ static bool classhook_repr_apply(pTHX_ ClassMeta *classmeta, SV *value, SV **att
   }
   else if(strEQ(val, "keys"))
     classmeta->repr = REPR_KEYS;
+  else if(strEQ(val, "pvobj")) {
+    if(classmeta->type == METATYPE_CLASS && classmeta->cls.foreign_new)
+      croak("Cannot switch a subclass of a foreign superclass type to :repr(pvobj)");
+#ifdef HAVE_SVt_PVOBJ
+    classmeta->repr = REPR_PVOBJ;
+#else
+    croak("Cannot switch to :repr(pvobj) on Perl " PERL_VERSION_STRING);
+#endif
+  }
   else if(strEQ(val, "default") || strEQ(val, "autoselect"))
     classmeta->repr = REPR_AUTOSELECT;
   else
